/* --------------------------------------------------------------
 index.js 2018-09-12
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2018 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

import renderIndex from './templates/index.pug';
import '../common/styles/main.scss';
import {setFooterYear} from '../common/scripts/footer';

$(function() {
    'use strict';
    
    $('#app').html(renderIndex());
    setFooterYear();
    
    $.getJSON('versions.php')
     .done(json => {
         const $referenceVersion = $('.reference-version');
        
         // Development Mode
         if (json[0] === '0.0.0.0') {
             $referenceVersion.hide();
             return;
         }
        
         $.each(json, (index, version) => {
             $referenceVersion.append(new Option('v' + version, version));
         });
        
         $referenceVersion.find('option:first').attr('selected', 'selected');
         $referenceVersion.trigger('change');
     })
     .fail((jqxhr, textStatus, error) => {
         console.info('Versions file could not be fetched.', jqxhr, textStatus, error);
         $('.select-version').hide();
     });
    
    $(document).on('change', '.reference-version', () => {
        // Update the documentation links.
        $('.available-documentation a').each((index, link) => {
            const href = $(link).data('dir')
                         ? 'docs/' + $('.reference-version').val() + '/' + $(link).data('dir')
                         : $(link)
                             .attr('href')
                             .replace(/\?v=.*/, '') +
                             '?v=' +
                             $('.reference-version').val();
            $(link).attr('href', href);
        });
        
        const versionParts = $('.reference-version').val().split('.');
        if (versionParts[0] === '2' || versionParts[0] === '3' || (versionParts[0] === '4'
            && parseInt(versionParts[1]) <= 3)) {
            $('a.rest-v3').css('cursor', 'not-allowed');
            $('a.tutorials-gx4').css('cursor', 'not-allowed');
            $('a.rest-v3').attr('title', 'Nicht verfügbar für diese Version.');
            $('a.tutorials-gx4').attr('title', 'Nicht verfügbar für diese Version.');
        } else {
            $('a.rest-v3').css('cursor', 'initial');
            $('a.tutorials-gx4').css('cursor', 'initial');
            $('a.rest-v3').attr('title', '');
            $('a.tutorials-gx4').attr('title', '');
        }
    });
    
    $('.available-documentation').on('click', 'a', e => {
        e.preventDefault();
        
        const $link = $(e.target);
        
        // Cancle click if it's REST API v3 does not exist
        if ($('.reference-version').val() !== null) {
            const versionParts = $('.reference-version').val().split('.');
            if (($link.hasClass('rest-v3') || $link.hasClass('tutorials-gx4'))
                && (versionParts[0] === '2' || versionParts[0] === '3' || (versionParts[0] === '4'
                    && parseInt(versionParts[1]) <= 3))) {
                return;
            }
        }
        
        // Disable scrolling before starting the animation.
        const scrollTop = $(window).scrollTop();
        window.onscroll = () => {
            window.scrollTo(0, scrollTop);
        };
        
        // Clone the original element and perform the animation with its clone.
        const $clone = $link.clone(),
            href = $link.attr('href'),
            offset = $link.offset();
        
        $clone.css({
            position: 'absolute',
            top: offset.top,
            left: offset.left,
            margin: '0',
            'z-index': '999999',
            'pointer-events': 'none'
        });
        
        $clone.prependTo($link.parent());
        
        const options = {
            top: scrollTop,
            left: '0',
            width: '50%',
            height: '100%',
            'padding-top': '40vh',
            'font-size': '10vh'
        };
        
        $clone.animate(options, 330, 'swing', () => {
            $('body').css('overflow', 'hidden');
            
            // Wait for a while and then fadeout the frame before leaving the page.
            setTimeout(() => {
                const options = {
                    color: 'white',
                    'background-color': 'white'
                };
                
                $clone.animate(options, 330, 'linear', () => {
                    location.href = href; // Navigate to the requested page.
                });
            }, 600);
        });
    });
});
