/* --------------------------------------------------------------
 Effects.js 2016-09-16
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

/**
 * Fade In Animation
 *
 * @param {HTMLElement} element Element to be faded.
 *
 * @return {Promise} Returns a promise which will be resolve once the animation is ready.
 */
export function fadeIn(element) {
	return new Promise(resolve => {
		if (element.style.opacity === '') {
			element.style.opacity = 0;
		}

		element.style.opacity = 0;

		(function update() {
			let currentOpacity = parseFloat(element.style.opacity);

			if ((currentOpacity += 0.1) <= 1) {
				element.style.opacity = currentOpacity;
				requestAnimationFrame(update);
			}

			resolve();
		})();
	});
}

/**
 * Fade Out Animation
 *
 * @param {HTMLElement} element Element to be faded.
 *
 * @return {Promise} Returns a promise which will be resolve once the animation is ready.
 */
export function fadeOut(element) {
	return new Promise(resolve => {
		if (element.style.opacity === '') {
			element.style.opacity = 1;
		}

		(function update() {
			element.style.opacity = parseInt(element.style.opacity) - 0.1;
			if (element.style.opacity < 0) {
				resolve();
				element.style.display = 'none';
			} else {
				requestAnimationFrame(update);
			}
		})();
	});
}
