/* --------------------------------------------------------------
 ScrollToTopButton.js 2016-09-22
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

/**
 * Creates a scroll-to-top button.
 *
 * @param {HTMLElement} container The container of the button.
 * @param {PerfectScrollbar} perfectScrollbarInstance PerfectScrollbarInstance used for various operations.
 */
export function createScrollToTopButton(container, perfectScrollbarInstance) {
	const button = document.createElement('button');
	button.classList.add('btn', 'scroll-to-top');
	if (container.scrollTop < 50) {
		button.classList.add('hidden');
	}
	button.setAttribute('title', 'Scroll nach oben');
	button.innerHTML = '<i class="fa fa-arrow-circle-o-up fa-2x"></i>';

	button.addEventListener('click', () => {
		if (container.classList.contains('ps')) {
			container.scrollTop = 0;
			perfectScrollbarInstance.update();
		} else {
			window.scrollTo(0, 0);
		}
	});

	// hide the scroll to top button if the container is scrolled to its bottom
	container.addEventListener('scroll', () => {
		// find if the container is scrolled to the bottom
		if (container.scrollTop < 50) {
			button.classList.add('hidden');
		} else {
			button.classList.remove('hidden');
		}
	});

	document.body.appendChild(button);
}
