const webpack = require('webpack');
const WebpackNotifierPlugin = require('webpack-notifier');
const HtmlWebpackPlugin = require('html-webpack-plugin');

module.exports = {
	entry: {
		index: './src/index/index.js',
		tutorials: './src/tutorials/tutorials.js',
		manual: './src/manual/manual.js',
	},
	output: {
		filename: '[name].js',
        chunkFilename: '[name]',
		path: __dirname + '/dist/app',
		publicPath: './app/'
	},
	devServer: {
		contentBase: './dist',
        watchContentBase: true,
        port: 9000,
		hot: true
	},
	plugins: [
	    new HtmlWebpackPlugin({
            filename: 'index.html',
            template: './dist/index.html',
            chunks: ['index']
        }),
        new HtmlWebpackPlugin({
            filename: 'tutorials.html',
            template: './dist/tutorials.html',
            chunks: ['tutorials']
        }),
        new HtmlWebpackPlugin({
            filename: 'manual.html',
            template: './dist/manual.html',
            chunks: ['manual']
        }),
		new WebpackNotifierPlugin(),
		new webpack.HotModuleReplacementPlugin(),
		new webpack.ProvidePlugin({
			$: 'jquery',
			jQuery: 'jquery'
		})
	],
	module: {
		rules: [
			{
				test: /\.js$/,
				exclude: /node_modules/,
				use: {
					loader: 'babel-loader',
					options: {
						presets: ['@babel/preset-env']
					}
				}
			},
			{
				test: /\.pug$/,
				use: [
					{
						loader: 'pug-loader'
					},
				]
			},
			{
				test: /\.(woff|woff2|ttf|svg|png|jpe?g|gif)(\?\S*)?$/,
				use: [
					{
						loader: 'url-loader',
						options: {
							limit: 8192
						}
					}
				]
			},
			{
				test: /\.css$/,
				use: [
					'style-loader',
					'css-loader'
				]
			},
			{
				test: /\.(eot)(\?\S*)?$/,
				use: [
					{
						loader: 'file-loader',
						options: {}
					}
				]
			},
			{
				test: /\.scss$/,
				use: [
					'style-loader',
					'css-loader',
					'sass-loader'
				]
			},
			{
				test: /\.js$/,
				exclude: /node_modules/,
				loader: 'eslint-loader'
			}
		]
	}
};